@@ -1,6 +1,7 @@
 use Log::Log4perl qw(:easy);
-use Log::Log4perl::CommandLine qw(log4perl.conf);
+use Log::Log4perl::CommandLine qw(:all :logconfig log4perl.conf);
 
+TRACE "trace message";
 DEBUG "debug message";
 INFO  "info  message";
 WARN  "warn  message";
